Kamis, 03 Oktober 2013

Daftar Kumpulan Simbol Komponen Listrik dan Elektronika Beserta gambarnya

Daftar Kumpulan Simbol Komponen Listrik dan Elektronika Beserta gambarnya


Belajar elektronika haruslah mengetahui, memahami dan hafal dengan simbol-simbol komponen yang digunakan dalam sebuah rangkaian elektronika. Memperbaiki televisi, radio, tape, VCD/DVD dan peralatan elektronika akan kesulitan jika tidak tahu simbol-simbol komponen yang digunakan dalam papan rangkaian elektronika.
Untuk anda yang sedang belajar elektronika atau ingin mempelajarinya, berikut ini adalah kumpulan daftar simbol elektronika dan dan simbol komponen listrik Beserta gambarnya .



SIMBOL NAMA KOMPONEN KETERANGAN
Simbol Sambungan
Simbol Kabel Kabel/ Wire Listrik Kabel penghubung (konduktor)
Simbol Kabel Terhubung Koneksi kabel Terhubung
Simbol Kabel Tak terhubung Kabel tidak koneksi Terputus (tidak terhubung)
Simbol Saklar (Switch) dan Simbol Relay
Simbol Saklar Toggle Switch SPST Terputus dalam kondisi open
Simbol Saklar Toggle Switch SPDT Memilih dua terminal koneksi
Simbol Saklar Saklar Push-Button (NO) Terhubung ketika ditekan
Simbol Saklar Saklar Push-Button (NC) Terputus ketika ditekan
Simbol Saklar DIP Switch Multiswitch(Saklar banyak)
Simbol Saklar Relay SPST Koneksi (Open dan Close) digerakan oleh elektromagnetik.
Simbol Saklar Relay SPDT
Simbol Saklar Jumper Koneksi dengan pemasangan jumper
Simbol Saklar Solder Bridge Koneksi dengan cara disolder
Simbol Ground
Simbol Ground Earth Ground Referensi 0 sebuah sumber listrik
Simbol Ground Chassis Ground Ground yang dihubungkan pada body sebuah rangkaian listrik
Simbol Ground Common/ Digital Ground
Simbol Resistor
Simbol Resistor Resistor Resistor berfungsi untuk menahan arus yang mengalir dalam rangkaian listrik
Simbol Resistor Resistor
Simbol Potensio Potensio Meter Menahan arus dalam rangkaian listrik tetapi nilai resistansi dari 3 titik terminal dapat diatur
Simbol Potensio Potensio Meter
Simbol Variable Resistor Variable Resistor Menahan arus dalam rangkaian listrik tetapi nilai resistansi dari 2 titik terminal dapat diatur
Simbol Variable Resistor Variable Resistor
Simbol Condensator (Kapasitor)
Simbol Condensator Condensator Bipolar Berfungsi untuk menyimpan arus listrik sementara waktu
Simbol Condensator Condensator Nonpolar
Simbol Condensator Condensator Bipolar Electrolytic Condensator (ELCO)
Simbol Condensator Kapasitor berpolar Electrolytic Condensator (ELCO)
Simbol Condensator Kapasitor Variable Condensator yang nilai kapasitansinya dapat diatur
Simbol Kumparan (Induktor)
Simbol Lilitan Induktor, lilitan, kumparan, spul, coil Dapat menghasilkan medan magnet ketika dialiri arus listrik
Simbol Lilitan Induktor dengan inti besi Kumparan dengan inti besi seperi pada trafo
Simbol Lilitan Variable Induktor Lilitan yang nilai induktansinya dapat diatur
Simbol Power Supply
Simbol Power Supply Sumber tegangan DC Menghasilkan tegangan searah tetap (konstan)
Simbol Power Supply Sumber Arus Menghasilkan sumber arus tetap
Simbol Power Supply Sumber tegangan AC Sumber teganga bolak-balik seperti dari PLN (Perusahaan Listrik Negara)
Simbol Power Supply Generator Penghasil tegangan listrik bolah-balik seperti pembangkit listrik di PLN (Perusahaan Listrik Negara)
Simbol Battery Battery Menghasilkan tegangan searah tetap
Simbol Battery Battery lebih dari satu Cell Menghasilkan tegagan searah tetap
Simbol Regulator Sumber tegangan yang dapat diatur Sumber tegangan yang berasal dari rangkaian listrik lain
Simbol Regulator Sumber arus yang dapat diatur Sumber arus yang berasal dari rangkaian listrik lain
Simbol Meter (Alat Ukur)
Simbol Volt Meter Volt Meter Mengukur tegangan listrik dengan satuan Volt
Simbol Ampere Meter Ampere Meter Mengukur arus listrik dengan satuan Ampere
Simbol Ohm Meter Ohm Meter Mengukur resistansi dengan satuan Ohm
Simbol Watt Meter Watt Metter Mengukur daya listrik dengan satuan Watt
Simbol Lampu
Simbol Lampu Lampu Akan menghasilkan cahaya ketika dialiri arus listrik
Simbol Lampu Lampu
Simbol Lampu Lampu
Simbol Dioda
Simbol Dioda Dioda Berfungsi sebagai penyearah yang dapat mengalirkan arus listrik satu arah (forward bias)
Simbol Dioda Zener Dioda Zener Penyetabil Tegangan DC (Searah)
Simbol Dioda Schottky Dioda Schottky Dioda dengan drop tegangan rendah, biasanya terdapat dalam IC logika
Simbol Dioda Varactor Dioda Varactor Gabungan Dioda dan Kapasitor
Simbol Dioda Tunnel Dioda Tunnel Dioda Tunnel
Simbol LED LED (Light Emitting Diode) Akan menghasilkan cahaya ketika dialiri arus listrik DC satu arah
Simbol Photo Dioda Photo Dioda Menhasilkan arus listrik ketika mendapat cahaya
Simbol Transistor
Simbol Transistor NPN Transitor Bipolar NPN Arus listrik akan mengalir (EC) ketika basis (B) diberi positif
Simbol Transistor PNP Transistor Bipolar PNP Arus listrik akan mengalir (CE) ketika basis (B) diberi negatif
Simbol Transistor Darlington Transitor Darlington Gabungan dari dua transistor Bipolar untuk meningkatkan penguatan
Simbol Transistor JFET N Transistor JFET-N Field Effect Transistor kanal N
Simbol Transistor JFET P Transistor JFET-P Field Effect Transistor kanal P
Simbol Transistor NMOS Transistor NMOS Transistor MOSFET kanal N
Simbol Transistor PMOS Transistor PMOS Transistor MOSFET kanal P
Simbol Komponen Lain
Simbol Motor Listrik Motor Motor Listrik
Simbol Trafo Trafo, Transformer, Transformator Penurun dan penaik tegangan AC (Bolak Balik)
Simbol Bel Listrik Bel Listrik Berbunyi ketika dialiri arus listrik
Simbol Buzzer Buzzer Penghasil suara buzz saat dialiri arus listrik
Fuse, Sikring Pengaman. Akan putus ketika melebihi kapasitas arus
Simbol Sikring Fuse, Sikring
Simbol Bus Bus Terdiri dari banyak jalur data atau jalur address
Simbol Bus Bus
Simbol Bus Bus
Simbol Opto Coupler Opto Coupler Sebagi isolasi antar dua rangkaian yang berbeda. Dihubungkan oleh cahaya
Simbol Speaker Speaker Mengubah signal listrik menjadi suara
Simbol Mic Mic, Microphone Mengubah signal suara menjadi arus listrik
Simbol Op-Amp Op-Amp, Operational Amplifier Penguat signal input
Simbol Schmitt Trigger Schmitt Trigger Dapat mengurangi noise
Simbol ADC ADC, Analog to Digital Mengubah signal analog menjadi data digital
Simbol DAC DAC, Digital to Analog Mengubah data digital menjadi signal analog
Simbol Oscillator Crystal, Ocsilator Penghasil pulsa
Simbol Antenna
Simbol Antenna Antenna Pemancar dan penerima signa radio
Simbol Antenna Antenna
Simbol Antenna Dipole Antenna Gabungan dari simple Antenna
Simbol Gerbang Logika (Digital)
Simbol Gerbang NOT NOT Gate Output akan merupakan kebalikan input
Simbol Gerbang AND AND Gate Output akan 0 jika salah satu input 0
Simbol Gerbang NAND NAND Gate Output akan 1 jika salah satu input 0
Simbol Gerbang OR OR Gate Output akan 1 jika salah satu input 1
Simbol Gerbang NOR NOR Gate Output akan0 jika salah satu input 1
Simbol Gerbang EX-OR EX-OR Gate Output akan 0 jika input sama
SImbol D-Flip-Flop D-Flip-Flop Dapat berfungsi sebagai penyimpad data
Simbol Multiplexer Multiplexer 2 to 1 Menyeleksi salah satu data input yang akan dikirim ke output
Simbol Multiplexer Multiplexer 4 to 1
Simbol D-Multiplexer D-Multiplexer 1 to 4 Menyeleksi data input untuk dikirim ke salah satu output

Perintah Dasar Console Linux, Perintah Dasar Console Linux, Cara Instal Aplikasi di linux



Perintah Dasar Console Linux

Perintah Dasar Console Linux - Pada postingan kali ini BLOGNYA SI IMIN akan memberikan sebuah informasi bagi kalian yang baru mempelajari linux baik itu di sekolah ataupun di bangku kuliah. Perintah-perintah (command) dasar di Linux di jalankan di suatu terminal shell yang biasa disebut terminal atau console. Terminal atau console ini dikenal dengan istilah command line interface (CLI) yang bisa diaktifkan dengan cara klik menu Applications – Accessories – Terminal. Selain itu bisa juga dengan bekerja diconsole murni dengan menekan kombinasi tombol ctrl+alt+F1 dimana F1 bisa diganti sampai F6. Untuk kembali ke mode Grafical User Interface (GUI) tekan ctrl+alt+F7.
Berikut beberapa Perintah Dasar Console Linux:
login: Untuk masuk ke dalam Jaringan.
password : Untuk memasukkan kata sandi setelah login.
who : Untuk mengetahui daftar pemakai yang sedang aktif (login).
finger : Menyediakan informasi identitas user yang lebih lengkap dari ada who.
logout : Untuk keluar dari sistem atau mengakhiri satu sesi login
whoami :  Untuk mengetahui user siapa yang digunakan sedang login di suatu komputer/terminal.
date : menunjukan / mengatur tanggal.
ls :  Menampilkan daftar file dalam directori aktif.
keterangan : Perintah ini akan menampilkan informasi mengenai directori dan file.Bentuk sederhana perintah ls akan menampilkan hanya nama file. Bentuk panjang ditandai dengan menggunakan option –l, yang akan menampilkan nama-nama file beserta informasi untuk setiap file yang ditampilkan. Beberapa option yang di sediakan antra lain sebagai berikut :
-a : Tampilkan semua file di directory termasuk isian.
-o :Tampilkan hanya nama directory
-g :Cetak ID kelompok hanya untuk bentuk panjang
-l :Tampilkan seluruh file secara lengkap
-r :Ubah urutan pengaturan nama file yang telah disusun
-t :Atur nama file berdasarkan waktu modifikasi terakhir, tidak berdasarkan nama
chmod : Mengubah permission suatu direktori/file.
contoh:  chmod 777 nama_file
clear :  berfungsi untuk membersihkan layar pada CLI
contoh : clear atau bisa juga menekan tombol ctrl + D

cmp : Membandingkan file1 dan file2 serta laporkan perbedaannya
contoh:  cmp file1 dan file2
cp : mengcopy file
contoh : # cp file1 /usr/lib
rm : menghapus file
contoh : rm namafileyangmaudihapus
mv :  memindahkan ato merename suatu file
contoh : # mv renamefile1 menjadifile2
cat : Menampilkan isi sebuah file (sama dengan perintah TYPE pada DOS). Cat berfungsi untuk mencetak ke layar monitor isi dari sebuah file text. Jika file dililihat menggunakan perintah ini bukan file text maka akan keluar karakterkarakter aneh pada  karakter-karakter aneh tersebut dapat digunakan perintah cat –v.layar.. Untuk menghindari tercetaknya
grep : mencari file di sembarang direktori
contoh : grep -n ‘namafile’ /direktori
mkdir :  membuat direktori
contoh : mkdir namadirektori
rmdir : menghapus direktori
contoh : rmdir namadirektori
cd : berpindah direktori
contoh : cd /pathdirektor

 

Fungsi Direktori di Linux


Saya akan coba menganalogikan fungsi dari directori yang ada di Linux dengan Windows 9x meskipun tidak dapat dikatakan sama persis.
/ : disebut juga root directori, seperti Windows/DOS kita mengenalnya dengan istilah main directory atau directori utama, C:, yang kemudian di dalamnya terdapat sub-sub directori.
/bin : berisi dengan aplikasi-aplikasi dasar Linux yang dapat diakses oleh semua user, di Windows kita mengenalnya dengan directori C:WindowsCommand
/usr : directori yang memuat aplikasi, dokumentasi, konfigurasi aplikasi, library, source aplikasi Linux.
/usr/bin: berisi dengan aplikasi-aplikasi Linux yang dapat diakses oleh semua user, di Windows kita mengenalnya dengan directory C:Program Files
/etc : berisi dengan file-file konfigurasi sistem, di Windows dapat dianggap sebuah directory yang berisi file-file dengan extension .INI atau .CFG.
/opt : hampir sama fungsinya dengan /usr/bin
/sbin : berisi aplikasi-aplikasi dasar yang hanya dapat diakses oleh root atau superuser.
/usr/sbin: berisi aplikasi-aplikasi untuk administrasi sistem lebih jauh lagi, dan hanya bisa diakses oleh root atau superuser.
/boot : berisi file-file yang berhubungan dengan kernel, kalau di Windows kita akan melihat file-file tersebut sebagai MSDOS.SYS, IO.SYS dan COMMAND.COM
/dev : berisi file-file yang mewakili hardware-hardware, misal Paralel Port (LPT) yang biasanya untuk Printer /dev/lpt, soundcard /dev/dsp, harddisk IDE Primary Master /hda, dan lain-lain
/lib : berisi file-file library, kalau di Windows kita akan melihat sebuah directory yang berisi file-file dengan extension .DLL
/usr/doc: berisi file-file dokumentasi Linux dan aplikasinya.

Cara Instal Aplikasi di linux
Proses instalasi paket aplikasi yang dicontohkan pada artikel ini menggunakan perintah di console, sesuai dengan paket aplikasi yang digunakan baik pada lingkungan linux maupun unix.
Hal yang perlu diingat sebelum melakukan instalasi paket aplikasi di linux dan unix adalah membaca dokumentasi yang disertakan pada setiap paket aplikasi yang akan diinstal. Adakalanya untuk paket aplikasi tertentu memiliki cara instalasi yang berbeda dengan cara umum yang dilakukan, ada baiknya mengikuti petunjuk yang tersedia terlebih dahulu jika ada.
Untuk paket aplikasi dari source (tarbal), yang berekstensi tar.gz dan tar.bz2 (masih merupakan baris-baris code, dan belum dikompilasi), langkah umum pertama yang dilakukan adalah mengekstrak paket aplikasi. dengan perintah :
Untuk rar dengan perintah dan opsi :
# unrar x [nama_paket].rar
Untuk xz dengan perintah dan opsi :
# unlzma [nama_paket].xz
Untuk Z dengan perintah dan opsi :
# uncompress [nama_paket].Z
Untuk 7z dengan perintah dan opsi :
# 7z x [nama_paket].7z
Untuk gz dengan perintah dan opsi :
# gunzip [nama_paket].gz
Untuk bz2 dengan perintah dan opsi :
# bunzip2 [nama_paket].bz2
Untuk tar dengan perintah dan opsi :
# tar -zxvf [nama_paket].tar
Untuk tar.gz dengan perintah dan opsi :
# tar -xzvf [nama_paket].tar.gz
Untuk tar.bz2 dengan perintah dan opsi :
# tar -xvjf [nama_paket].tar.bz2
Untuk ZIP dengan perintah dan opsi:
#unzip [nama_paket].zip
Tahap dan proses yang dilakukan adalah konfigurasi instalasi, kompilasi (compiling) code, dan proses instalasi binari.
Setelah diekstrak, selanjutnya melakukan konfigurasi instalasi. Proses ini merupakan tahap pra-instalasi sebuah paket aplikasi. Dimana pada proses ini akan dilakukan beberapa persyaratan pengujian terhadap sistem yang digunakan dan akan membuat sebuah file bernama “Makefile” yang berguna untuk menjelaskan dan membuat aturan bagaiman aplikasi perangkat lunak harus dikompilasi.
# cd [nama_direktori]
# ./configure
Pada tahap ini, dapat diatur dimana aplikasi akan disimpan dengan menambahkan perintah –prefix setelah perintah di atas.
# ./configure --prefix [path_direktori_tujuan]
Setelah menunggu proses pra-instalasi ini selesai, selanjutnya melakukan kompilasi terhadap baris-baris code aplikasi tersebut, dengan perintah :
# make
Proses terakhir, setelah dikompile, akan dilakukan instalasi binari hasil kompilasi. Proses ini akan menyimpan binari-binari hasil kompilasi tadi ke lokasi permanen aplikasi ditempatkan. Untuk melakukan ini, biasanya hanya dengan akses root, pastikan bahwa kita menjalankan mode root pada proses ini, dan ketikkan perintah :
# make install
Jika tidak terdapat pesan error, maka instalasi aplikasi telah sukses dilakukan. Aplikasi sudah dapat digunakan.
Untuk update paket aplikasi yang berasal dari source ini bisa langsung menimpanya saja, dan uninstall cukup dengan menghapus folder hasil copy yang telah disimpan di hardisk. 
Instalasi paket RPM
RPM merupakan sebuah software manajemen aplikasi di lingkungan distro berbasis RPM (turunan Redhat dan Fedora). Software RPM ini memberikan kemudahan bagi penggunanya untuk menggunakan aplikasi berekstensi .rpm. Paket-paket .rpm ini telah dikompilasi, jadi proses instalasi hanya akan melakukan ekstrak paket dan melakukan copy ke lokasi direktori tempat aplikasi akan disimpan.
Untuk proses instalasi cukup sederhana, dengan perintah :
# rpm -i [nama_file].rpm
Untuk uninstall dengan perintah :
# rpm -e <package>
Opsi -i berarti install dan -e berarti erase. Untuk pilihan lainnya bisa dilihat di manual rpm :
# man rpm
Instalasi paket DEB
Sama seperti paket rpm, deb juga sudah dikompilasi ke binari. Hanya melakukan instalasi dengan proses ekstrak paket dan melakukan copy binari ke direktori hardisk. Untuk instalasi paket deb, dengan menggunakan perintah :
# dpkg -i [nama_paket].deb
Untuk uninstall dengan perintah :
# dpkg -r [nama_paket].deb
Opsi -i berarti install dan -r berarti remove. Untuk pilihan lainnya dapat dilihat pada manualnya :
# man dpkg
Instalasi binari File dan script .sh
Adakalanya kita menggunakan file binari atau script .sh juga, untuk proses instalasi nya dengan perintah sh. Tapi sebelum menjalankan script atau file binari ini pastikan bahwa file tersebut sudah memiliki akses execute. Untuk pengecekannya dengan perintah :
# ls -l
Untuk memberikan akses ijin execute pada file script, dengan perintah :
# chmod +x [nama_file]
Setelah itu, tinggal eksekusi file tersebut dengan perintah :
# sh [nama_file]
Untuk beberapa distro, proses instalasi ini bisa dilakukan dengan bantuan software manajemen aplikasi yang tersedia dan dikembangkan masing-masing distro.
Instalasi paket .run
#chmod +x [nama_file].run
#./[nama_file].run
Troubleshooting
Jika terdapat pesan error dalam proses instalasi seperti yang telah dijelaskan di atas, periksalah kembali perintah dan file yang akan diinstal. Beberapa masalah umum yang biasanya timbul saat melakukan proses instalasi paket aplikasi tersebut adalah :
  • Akses izin untuk melakukan instalasi, dimana untuk proses instalasi umumnya hanya bisa dilakukan oleh root. User yang akan melakukan instalasi haruslah dengan autorisasi root terlebih dahulu. Untuk manajemen hak ini bisa langsung dengan bantuan root atau dengan sudo.
  • Error instalasi, hal ini bisa saja terjadi karena belum sempurna nya paket aplikasi didownload atau tidak kesesuaian paket aplikasi. Cek besar file dan md5 sum untuk memastikan paket aplikasi didownload valid. Jika tidak sesuai, lakukan download ulang paketnya, dan ulangi proses yang dilakukan sebelumnya.
  • Error saat menjalankan file binari atau script, pastikan bahwa file binari atau script diberikan akses execute, jika belum dapat dilakukan dengan bantuan perintah chmod.
  • Error saat kompilasi atau saat instalasi paket dikarenakan dependensi (ketergantungan) paket terhadap paket lain. Untuk kasus ini, haruslah melakukan instalasi paket aplikasi yang dibutuhkan terlebih dahulu untuk instal paket yang diinginkan.


Jumat, 20 September 2013

Cara Memasang Spul Speaker Sendiri

Cara Memasang Spul Speaker Sendiri.

Inilah tips cara memperbaiki speaker yang suaranya jebol atau pecah- pecah



 
        Zaman sekarang banyak orang yang sudah pandai di bidang elektronika. Karena dengan semaraknya media penyampai bidang teknologi, baik melalui media elektronika maupun media cetak. Ilmu itu diperoleh baik secara otodidak ataupun hasil mereka magang pada salah satu toko reparasi elektronika. Tapi yang penting mereka mendapat nilai tambah baik secara ekonomi maupun secara didikasi. Bagi mereka yang saat ini suka
dengan dunia sound system sangatlah cocok karena tidak menutup kemungkinan dari peralatan mereka pada suatu saat akan mengalami kerusakan. Baik itu Mixer, Power Soud Amplifier dan lebih-lebih Spul pada speakernya. Nah mari kita membahas bersama secara sederhana cara memasang sendiri spul speaker kita yang rusak akibat kelebihan beban daya out put power amplifier sehingga spulnya terbakar. Lumayang mudah dan menghemat biaya. Tapi yang penting kita harus mengerti dan mampu menggunakan alat bantu yang dipakai untuk mereparasi speaker kesayangan kita yang telah terbakar spulnya tadi.
Ciri-ciri spul speaker rusak.
1. Tidak bunyi sama sekali ( jika perkawatan udah di cek )
2. Kalau toh berbunyi, sangat pelan ( krek.. kre..k )
3. Berbau sangit ( khas benda terbakar )
4. Bisa umpan balik ke power. semacan konsleting (hubungan singkat)
Alat yang disiapkan :
1. Lem kastol dan lem besi dua isi yang warnanya jernih lihat aturan penggunaan. (maaf gak nyebut 
    merk lem) lem 
    ini    banyak dijual di pasaran apalagi di toko elektronikan di kota anda atau di toko bangunan terdekat.
 
2. Cutter. atau pemotong kecil yang dimodifikasi kaya clurit tapi ukurannya kecil. agar mudah
    untuk membersikan bekas lem sisa spul yang terbakar.
3. Gunting.
4. Klise atau bekas film. Kalau gak ada bisa pakai mika yang aga tebal setebal klise.
 klise
5. Solder 40 watt dengan timah  kualitas 40/60
Baha yang disediakan
1. Spul speaker. spul harus sesuai dengan ukuran spesifikasi aslinya. baik mengenai diameter 
    lingkaran spulnya ataupun ukuran kawatnya.
2. Kabel elastis. barangkali perlu diganti. Jika tidak tetap menggunakan yang lama.
 
  cara memasang spul salon (speaker)
1. Buka spul  speaker yang terbakar tadi pelan pelan. Jangan sampai merusak kertas resonansinya.
2. Bersikahkan dari sisa arang atau sisa pembakaran spul.
3. Lebarkan sedikit lubang tempat spul dengan cater agar mudah memasukanya.
4. Masukkan spul jangan terlalu kedalam atau sebaliknya. usahakan sesuaikan dengan permukaan
    ujung magnet dengan batas lilitan spul yang atas.
5. Kuncilah hasil pemasangan spul tadi dengan plastik film agar bisa pas dan tidak begeser dengan logam 
   di kiri kanannya.
6. Aduk lem tadi dengan benar. Kemudian oleskan dengan baik pada spul dengan kertas resonannya.
    Jangan lupa jika lem sudah kering betul , plastik filem harus diambil.
7. Kelupas ujung spul dengan yang menuju ke pin.
8. Solder kawat tadi dengan pin yang menghubungkan ke terminal + - speaker. Jangan lupa kawat tadi
    juga di lem dengan kertas lesonan agar awet dan tidak mudak rusak/putus.
9. Cek dengan AVO meter pada 1X ohm. Nyambung dan berbunyi  krek.. krekk...
    Coba dipasang ampli. hasilnya bagaimana ???
10 Selesai.
Begitu mudahnya kita belajar memperbaiki speaker kita sendiri.
Secara ekonomis kita menghemat biaya. Semoga anda understand dengan sedikit penjelasan saya dan ada manfaatnya.



SELAMAT MENCOBA MOGA LANCAR AJA.

menggerakan cursor tanpa mouse

Cara Menggerakan Kursor Tanpa Mouse

Tips untuk menggerakkan kursor dengan keyboard apabila mouse anda rusak.
Langkah-langkahnya adalah sebagai berikut:
  1. Tekan tombol ALT + Shift + NumLock secara bersamaan. Cara ini akan memunculkan windows MouseKeys.
  2. Selanjutnya klik tombol Settings, beri tanda centang pada pilihan Use MouseKeys. Nah sampai disini fungsi mousekeys sudah aktif.
Silahkan coba menggerakkan kursor menggunakan tombol-tombol angka di keypad numerik.
Angka 1, 2, 3, 4, 6, 7, 8, dan 9 digunakan untuk menggerakkan kursor ke atas, bawah, samping kanan/kiri, dan ke arah diagonal.
Sedangkan angka 5 berfungsi seperti tombol “klik” pada mouse.
Untuk “drag & drop” gunakan kombinasi angka dengan tombol “insert”.

Selasa, 30 Juli 2013

cara membuat amplifer dengan power usb

Berikut skematik USB-mini amplifier model push-pull yang akan kita realisasikan projeknya dari komponen bekas pesawat telepon:

Singkatnya, inilah cara merakitnya:
(1) Bongkarlah pesawat telepon rusak tsb, congkel dan ambil semua komponennya (transistor, resistor, diode, elco, dan speaker) dengan bantuan solder dan pinset.
(2) Lakukan TEST pada semua komponen dengan Multitester, komponen yg sudah rusak dibuang, komponen yang masih bagus disimpan untuk dipakai merakit speaker aktif. Komponen semikonduktor berupa Transistor dan Diode biasanya masih bagus, karena jenis komponen ini termasuk yang “tahan banting”, kerusakan biasanya pada resistor.
(3) Siapkan komponen yg masih bagus untuk merakit speaker aktif berupa: Transistor 3 bh (2 tipe NPN, 1 tipe PNP), 1 speaker, 2 elco dan 6 resistor dengan ukuran seperti pada skema di atas.
(4) Ukuran Elco dan Resistor tidak harus sama persis dengan ukuran yg tertera pada skema di atas, bisa diganti dengan ukuran yang mendekati (asal selisihnya tidak terlalu jauh) disesuaikan dengan yang tersedia dari hasil bongkaran pesawat telpon tadi.
(5) Siapkan PCB “bolong-bolong” (atau PCB Kosong) untuk tempat dudukan komponen, PCB bisa dibeli dari toko elektro. Jika mau “ngirit” lagi, PCB bisa dibuat dari TRIPLEK atau papan kayu tipis.
(6) Siapkan jalur-jalur dari kawat kabel tembaga dengan alur seperti pada skema di atas sebagai tempat dudukan kaki-kaki komponen, dengan cara disolder pada PCB tadi. Jika menggunakan PCB dari Triplek atau kayu, tersebih dahulu dipasang paku-paku kecil pada triplek/kayu tersebut, terus jalur kabel disolderkan pada paku kecil tsb.
(7) Mulailah memasang komponen dengan cara disolderkan kaki-kakinya pada jalur kawat tembaga yg telah kita buat tersebut.
(8) Hati hati dalam memasang komponen, semikonduktor (dioda dan transistor) jangan sampai terbalik polaritasnya.
(9) Pastikan pemasangan Transistor tidak salah tipenya. Untuk tipe NPN jangan dipasang yang PNP, atau sebaliknya. Harus tepat sesuai dengan tipe yg seharusnya di pasang (lihat kembali skema di atas). Kaki-kaki Basis, Kolektor, Emitor harus dipasang secara tepat, jangan sampai terbalik.
(10) Diode harus dipasang tepat polaritasnya, perhatikan pada skema di atas. Polaritas Anoda dan Katodanya jangan sampai terbalik, karena jika terbalik tidak akan menghasilkan “bunyi” akibat tidak adanya suply balance Tr NPN-PNP.
(11) Elco sebaiknya dipasang tepat polaritasnya, jika pun terbalik juga tidak apa-apa, hanya akan mengurangi kualitas/linieritas pada suaranya.
(12) Resistor dan Speaker tidak ada polaritasnya, bisa dipasang bolak-balik.
(13). SELESAI. Siap dicolokkan pada komputer/laptop/netbook.
O ya, karena komponen pada pesawat Telpon mungkin berbeda-beda tergantung jenis dan merk telponnya, kemungkinan beberapa komponen tidak tersedia. Solusinya, di bawah ini saya sajikan skematik mini amplifier yang lebih sederhana lagi, dari modifikasi skema di atas. Jumlah Resistor (R) dikurangi. R 10K input bisa dihilangkan karena fungsinya hanya pembatas beban input. R output 1 ohm 2 buah pada output sebelum Elco kopel juga bisa dinetralkan dengan koneksi kabel langsung. Untuk R 100K dialikan sambungannya ke balance Tr Final untuk mendapatkan suply tegangan Basis Tr Pertama yg lebih besar. Skema modifikasi sederhana sbb:

Jika Resistor atau Elco dengan nilai tersebut pada gambar tidak tersedia, dapat disubstitusi dengan nilai lain yang mendekati.
Selamat mencoba !!!